#!/usr/bin/ruby -w

$stderr.reopen('/dev/null', 'w')
require "glib2"
require "gtk2"
$stderr=STDOUT

require "eataria2"
require "eatmanager"

include Gtk

if __FILE__ == $0
	if not GLib::Thread.supported?
		GLib::Thread.init()
	end

	aria2 = Eat::Aria2Listener.instance
	settings = Eat::Settings.instance
	if settings["custom-server"]
		aria2.use_custom_server(settings["xmlrpc-host"], settings["xmlrpc-port"], settings["xmlrpc-user"], settings["xmlrpc-passwd"])
	end
	aria2.connect

	manager = Eat::Manager.new
	manager.show

	main
end

